From 940c34742e5f94ef3929c214bed221815940662b Mon Sep 17 00:00:00 2001
From: Srikanth Kurapati <srikanth.kurapati@multicorewareinc.com>
Date: Wed, 14 Oct 2020 13:40:10 +0530
Subject: [PATCH] Wiki changes for x265 Release 3.5

Archival procedure updates plus general edits in home and contribute pages
---
 Contribute.md | 14 ++++++------
 Home.md       | 60 ++++++++++++++++++++++++++++++++++++++++++++-------
 2 files changed, 59 insertions(+), 15 deletions(-)

diff --git a/Contribute.md b/Contribute.md
index 5fd299c..168c699 100644
--- a/Contribute.md
+++ b/Contribute.md
@@ -13,7 +13,7 @@ We use a mailing list to communicate and review patches:
 
 ## Contributor License Agreement ##
 
-As is common for Open Source projects, we require a signed [contributor agreement](https://bitbucket.org/multicoreware/x265_git/downloads/x265ContributorAgreement.pdf)
+As is common for Open Source Projects, we require a signed [contributor agreement](https://bitbucket.org/multicoreware/x265_git/downloads/x265ContributorAgreement.pdf)
 before we can accept changes.  This protects the project from being sued by former
 contributors (or their employers) for copyright or patent infringement.
 
@@ -142,12 +142,12 @@ Once your patch is approved and pushed to the x265 Git repository, we have autom
 
 If you introduce a new x265_param member, you must add documentation for it and make it fully configurable.
 
-1. x265.h needs good documentation
+1. x265.h needs good documentation in comments in the param data structures.
 2. x265_param_parse() must be updated
 3. x265_param2string() must be updated
-4. getopt() (and CLI help) support needs to be added to x265cli.h
-5. the param must be documented in doc/reST/cli.rst
-6. X265_BUILD must be incremented, the binary interface has changed
-7. test(s) have to be added to smoke-tests.txt and regression-tests.txt
+4. getopt() (and CLI help) support needs to be added to x265cli.h and cpp files
+5. The param option usage and relevance must be documented in doc/reST/cli.rst and corresponding rst documentation files.
+6. X265_BUILD must be incremented, as the binary interface has changed.
+7. TestCases have to be added to smoke-tests.txt and regression-tests.txt.
 
-Much of the above is also true if you change any public function definitions or public structures.
\ No newline at end of file
+Much of the above is also true if you change any public function definitions or public structures available as part of API to the library.
\ No newline at end of file
diff --git a/Home.md b/Home.md
index 8f36e14..e72853e 100644
--- a/Home.md
+++ b/Home.md
@@ -25,13 +25,59 @@ MD5 (x265_3.1.2.tar.gz) = a528ab27660d6bcfc46188ae602b3c2e
 MD5 (x265_3.2.tar.gz) = 374e6359a00d17fd82195c02c341c861
 MD5 (x265_3.2.1.tar.gz) = 94808045a34d88a857e5eaf3f68f4bca
 ```
+# Preparing Git Release tar balls
 
+Source release tar balls can be created by the following procedure displayed below.
+
+$ pwd
+D:\Projects\x265_v3.5
+$ ls x265version.txt
+x265version.txt
+
+In case of absence of file
+$ touch x265version.txt
+$ vi x265version.txt
+
+## HOW TO POPULATE THE FILE ##
+```
+The purpose of the file is to statically maintain version information for archived repositories.
+A line in the file providies the information in key value pairs format <Key: Value>. The following
+set of key pairs are required for complete display of version string on the console. 
+## VERSION INFORMATION FORMAT ##
+## Name: Values ##
+releasetag: refers to latest version tag for customers, users, developers and contributors in stadard format [x.x]+ or x.x_RC[number]
+releasetagcommitid: provides git generated SHA-1 key changeset string of release tag
+releasetagdistance: a whole number of updates attop of release for customer support and quality assurance
+repositorychangeset: is a git generated SHA-1 key changeset string of latest commit (OPTIONAL FOR release tagging)
+
+EXAMPLES:
+For tar ball generation of Release Tag.
+## Name: Values ##
+releasetag: 3.4
+releasetagcommitid: a82c6c7
+repositorychangeset: a82c6c7
+releasetagdistance: 0
+
+When archives genearated after Release for customers, users etc..
+
+## Name: Values ##
+releasetag: 3.5
+releasetagcommitid: af23ad2
+releasetagdistance: 28
+repositorychangeset: a82c6c7
+
+After filling the x265version file for git repositories and saving the same.
+$git archive --format=tar.gz -o x265-3.5.tar.gz --prefix=x265-test/ HEAD
+
+In case of multiple entries for the release information attribute value pairs. The latest of the set of required attributes in file will be considered.
+In order to prepare archives for various tag user can provides tagname instead of head or reference commitid. Please refer to [documentation](https://x265.readthedocs.io/en/master/) for version option details.
+```
 # Building x265
 
-To compile x265 you must first install Git and [CMake](http://www.cmake.org/cmake/resources/software.html) 2.8.8 or later.
+To compile x265 you must first install Git (for live repositories) and [CMake](http://www.cmake.org/cmake/resources/software.html) 2.8.8 or later.
 To ensure your build of x265 is capable of full performance, install
 [YASM](http://www.tortall.net/projects/yasm/releases) 1.2.0 or newer if you are using x265 v2.6 or older, or
-[NASM](http://www.nasm.us/pub/nasm/releasebuilds/?C=M;O=D) 2.13 or newer if you are compiling from the default branch to compile
+[NASM](http://www.nasm.us/pub/nasm/releasebuilds/?C=M;O=D) 2.13 or newer if you are compiling from the master branch to compile
 assembly primitives.  Then follow these easy steps:
 
 For detailed instructions, consult our build [README](https://bitbucket.org/multicoreware/x265_git/src/master/build/README.txt).  Basic instructions are outlined below.
@@ -46,11 +92,10 @@ $ sudo apt-get install git-all cmake cmake-curses-gui build-essential yasm
 $ git clone https://bitbucket.org/multicoreware/x265_git.git
 $ cd x265/build/linux
 $ ./make-Makefiles.bash
-$ make
+$ make -j8 
 ```
-
-The primary target that we support is x86. x265 can also be built on linux platforms on ARM and POWERPC targets using the same build insructions above
-(exclude yasm from the list of packages on these targets). Our support for these platforms is growing as our user base on these platforms increase.
+The primary target hardware architecture that we support is x86. x265 can also be built on linux platforms on ARM and POWERPC target machines using the same build insructions above
+(exclude yasm from the list of packages on these target platforms). Our support for these platforms is growing as our user base on these platforms is increasing.
 
 We also support cross-compilation for ARM targets from linux platforms on x86 targets by using the g++ arm cross-compiler. This has been tested on Ubuntu linux
 14.04 running on an x86 CPU. On other distributions, package names and names of cross compilation tools may differ. This is an experimental feature, and has undergone very limited testing. 
@@ -60,13 +105,12 @@ $ sudo apt-get install git-all cmake cmake-curses-gui build-essential gcc-arm-li
 $ git clone https://bitbucket.org/multicoreware/x265_git.git
 $ cd x265/build/arm-linux
 $ ./make-Makefiles.bash
-$ make
+$ make -j8
 ```
 ## Windows (Visual Studio) Instructions ##
 ```
 $ git clone https://bitbucket.org/multicoreware/x265_git.git
 ```
-
 Then run make-solutions.bat in the build\ folder that corresponds to
 your favorite compiler, configure your build options, click 'configure',
 click 'generate', then close cmake-gui.  You will be rewarded with an
-- 
2.20.1.windows.1

